<?php

/**
 * @file
 * Provides views data for the Details Field module.
 */

use Drupal\field\FieldStorageConfigInterface;

/**
 * Implements hook_field_views_data().
 */
function details_field_field_views_data(FieldStorageConfigInterface $field): array {
  $data = views_field_default_views_data($field);
  $field_name = $field->getName();

  $columns = [
    'value' => 'standard',
    'summary' => 'standard',
    'open' => 'boolean',
    'name' => 'standard',
    'attributes' => 'standard',
  ];
  $labels = [
    'value' => t('Content'),
    'summary' => t('Summary'),
    'open' => t('Open'),
    'name' => t('Name'),
    'attributes' => t('Attributes'),
  ];
  $descriptions = [
    'value' => t('The details element content.'),
    'summary' => t('The details element summary.'),
    'open' => t('Defines if the details element is set to be open by default.'),
    'name' => t('The value of the attribute name for the details element.'),
    'attributes' => t('Extra attributes for the details element.'),
  ];
  $types = [
    'field',
    'filter',
    'sort',
    'argument',
  ];

  foreach ($data as $table_name => $table_data) {
    if (isset($table_data[$field_name])) {
      $base = $table_data[$field_name];
      foreach ($columns as $column => $plugin_id) {
        foreach ($types as $type) {
          if (isset($data[$table_name][$field_name . '_' . $column][$type]) || $type == 'field') {
            $plugin_id = $plugin_id === 'standard' && in_array($type, ['filter', 'argument']) ? 'string' : $plugin_id;
            $data[$table_name][$field_name . '_' . $column][$type]['title'] = $base['title'] . ' - ' . $labels[$column];
            $data[$table_name][$field_name . '_' . $column][$type]['id'] = $plugin_id;
            $data[$table_name][$field_name . '_' . $column][$type]['help'] = $descriptions[$column];
            $data[$table_name][$field_name . '_' . $column][$type]['field_name'] = $field_name;
            $data[$table_name][$field_name . '_' . $column][$type]['property'] = $column;
          }
        }
      }
    }
  }

  return $data;
}
