<?php

namespace Drupal\details_field;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\Plugin\Discovery\ContainerDerivativeDiscoveryDecorator;
use Drupal\Core\Plugin\Discovery\YamlDiscovery;

/**
 * Provides the details_field plugin manager.
 */
class DetailsFieldManager extends DefaultPluginManager implements PluginManagerInterface {

  /**
   * Constructs the DetailsFieldManager object.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   */
  public function __construct(ModuleHandlerInterface $module_handler, CacheBackendInterface $cache_backend) {
    $this->moduleHandler = $module_handler;
    $this->setCacheBackend($cache_backend, 'details_field', ['details_field']);
  }

  /**
   * {@inheritdoc}
   */
  protected function getDiscovery() {
    $this->discovery = new YamlDiscovery('allowed_attributes', $this->moduleHandler->getModuleDirectories());
    $this->discovery = new ContainerDerivativeDiscoveryDecorator($this->discovery);
    return $this->discovery;
  }

  /**
   * Gets attribute options from plugin definitions.
   *
   * @return array
   *   Array containing attribute options.
   */
  public function getOptionsFromDefinitions(): array {
    $definitions = $this->getDefinitions();
    $options = [];
    foreach ($definitions as $key => $definition) {
      $options[$key] = $definition['title'];
    }
    return $options;
  }

}
